/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef  _NEIGHBORJOIN_PLUGIN_H_
#define  _NEIGHBORJOIN_PLUGIN_H_

#include <U2Core/PluginModel.h>
#include <U2Core/AppContext.h>
#include <U2Gui/ObjectViewModel.h>

#include <QtGui/QMenu>

namespace U2 {


class PhylipPlugin : public Plugin {
	Q_OBJECT
public:
    static const QString PHYLIP_NEIGHBOUR_JOIN;
    PhylipPlugin();
	~PhylipPlugin();
};


} //namespace

#endif
